Changelog
=========


1.1.0 (2020-06-09)
------------------

- Revert "Fix missing dependency (breaks cpskin.core tests)"
  [mpeeters]

- Remove unwanted dependencies
  [mpeeters]

- Avoid UnicodeEncodeError if gdpr text browser view is already Unicode
  [laulaz]


1.0.4 (2019-11-20)
------------------

- Fix WrongType when inserting string in registry
  [laulaz]

- Fix missing dependency (breaks cpskin.core tests)
  [laulaz]

- Add css for document.
  [mgennart]

1.0.3 (2018-08-26)
------------------

- Inherit from website content styles
  [mpeeters]


1.0.2 (2018-07-16)
------------------

- Avoid an error when the package is not installed
  [mpeeters]


1.0.1 (2018-06-18)
------------------

- Translations
  [bsuttor]


1.0.0 (2018-06-14)
------------------

- Update gdpr default template.
  [bsuttor]


1.0a4 (2018-06-13)
------------------

- Add is_text_ready record.
  [bsuttor]


1.0a3 (2018-05-31)
------------------

- Use view instead of page.
  [bsuttor]


1.0a2 (2018-05-31)
------------------

- Fix i18n compilation.
  [bsuttor]


1.0a1 (2018-05-31)
------------------

- Initial release.
  [bsuttor]
